# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
allow_arbitrary_install = True
java8_jre_package_order_list_any_prefix = [
    "tis-oracle-java8-jre-free",
    "tis-oracle-java8-jre-nonfree",
    "tis-adoptopenjdk8-jre",
    "tis-adoptium-openjdk8-jre",
    "tis-adoptium-openjdk8-jdk",
]


def install():
    # Declaring local variables
    package_prefix = control.package.split("-", 1)[0]
    java8_jre_package_order_list = [package_prefix + "-" + x.split("-", 1)[1] for x in java8_jre_package_order_list_any_prefix]
    java8_jre_found = False

    print("Installing: %s" % control.package)
    if [y for y in java8_jre_package_order_list if WAPT.is_installed(y)]:
        java8_jre_found = True
        print("OK: A Java Runtime Environment 8 (JRE) is already installed with WAPT")
    else:
        if allow_arbitrary_install:
            print(
                "WARNING: A Java Runtime Environment 8 (JRE) will be installed with WAPT since this package allow arbitrary install based on available package in a specific order"
            )
            for package_name in java8_jre_package_order_list:
                if WAPT.is_available(package_name):
                    java8_jre_found = True
                    print("Installing: %s" % package_name)
                    WAPT.install(package_name)
                    break
        if not java8_jre_found:
            error(
                "ERROR: No Java Runtime Environment 8 (JRE) have been deployed on this system, please import and deploy the package adapted to your organization"
            )
